Method: FireRuby::AddUser#execute
- Defined in:
- lib/src.rb
#execute(manager) ⇒ Object
This method executes the add user task against a service manager.
Parameters
- manager
-
A reference to the ServiceManager object to execute the task on.
Exceptions
- FireRubyException
-
Generated whenever a disconnected service manager is specified or an error occurs executing the task.
1336 1337 |
# File 'lib/src.rb', line 1336 def execute(manager) end |