Method: FireRuby::Backup#log
- Defined in:
- lib/src.rb
#log ⇒ Object
This method fetches the log value for a Backup task. This value will always be nil until the task has been executed. After a successful execution the log value should contain output from the backup task generated on the server.
1562 1563 |
# File 'lib/src.rb', line 1562 def log end |