Method: FireRuby::Restore#log
- Defined in:
- lib/src.rb
#log ⇒ Object
This method fetches the log value for a Restore task. This value will always be nil until the task has been executed. After a successful execution the log value should contain output from the restore task generated on the server.
1792 1793 |
# File 'lib/src.rb', line 1792 def log end |