Method: FireRuby::Transaction#initialize
- Defined in:
- lib/src.rb
#initialize(connections) ⇒ Transaction
This is the constructor for the Transaction class.
Parameters
- connections
-
Either a single instance of the Connection class or an array of Connection instances to specify a multi-database transaction.
Exceptions
- Exception
-
Generated whenever the method is passed an invalid parameter or a problem occurs creating the transaction.
403 404 |
# File 'lib/src.rb', line 403 def initialize(connections) end |